/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.session;

import java.util.ArrayList;
import java.util.List;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;

import kieker.analysis.model.analysisMetaModel.MIPlugin;

/**
 * This bean can be used to save the currently selected plugin of the user.
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
@ManagedBean
@SessionScoped
public final class SelectedPluginBean {

	/**
	 * The plugin which is stored by this container.
	 */
	private MIPlugin plugin;

	/**
	 * Creates a new instance of this class.
	 */
	public SelectedPluginBean() {
		/* No code necessary. */
	}

	/**
	 * Delivers the stored plugin.
	 * 
	 * @return The plugin within this container.
	 */
	public MIPlugin getPlugin() {
		return this.plugin;
	}

	/**
	 * Sets the plugin stored by this bean.
	 * 
	 * @param plugin
	 *            The new bean to be stored within this bean.
	 */
	public void setPlugin(final MIPlugin plugin) {
		this.plugin = plugin;
	}
    
    public List<Object> getAdvancedProperties() {
        final List<Object> resultList = new ArrayList<Object>();
        
        resultList.add(plugin.getName());
        resultList.addAll(plugin.getProperties());
        
        return resultList;
    }
}
